import React, { useState, useRef, useEffect, useMemo, useCallback } from "react";
import { useNavigate } from 'react-router-dom';
import {
    List,
    DatagridConfigurable,
    SearchInput,
    TopToolbar,
    SelectColumnsButton,
    EditButton,
    FilterButton,
    CreateButton,
    ExportButton,
    BulkDeleteButton,
    WrapperField,
    useRecordContext,
    useTranslate,
    useNotify,
    useListContext,
    FunctionField,
    TextField,
    NumberField,
    DateField,
    BooleanField,
    ReferenceField,
    TextInput,
    DateTimeInput,
    DateInput,
    SelectInput,
    NumberInput,
    ReferenceInput,
    ReferenceArrayInput,
    AutocompleteInput,
    DeleteButton,
} from 'react-admin';
import { Box, Typography, Card, Stack } from '@mui/material';
import { styled } from '@mui/material/styles';
import CompanysCreate from "./CompanysCreate";
import CompanysPanel from "./CompanysPanel";
import EmptyData from "../../components/EmptyData";
import MyCreateButton from "../../components/MyCreateButton";
import MyExportButton from '../../components/MyExportButton';
import PageDrawer from "../../components/PageDrawer";
import DictField from "../../components/DictField";
import DictSelect from "../../components/DictSelect";
import { PAGE_DRAWER_WIDTH, OPERATE_MODE, DEFAULT_PAGE_SIZE } from '@/config/setting';
import * as Common from '@/utils/common';

const StyledDatagrid = styled(DatagridConfigurable)(({ theme }) => ({
    '& .css-1vooibu-MuiSvgIcon-root': {
        height: '.9em'
    },
    '& .RaDatagrid-row': {
        cursor: 'auto'
    },
    '& .column-name': {
    },
    '& .opt': {
        width: 200
    },
}));

const filters = [
    <SearchInput source="condition" alwaysOn />,
    <TextInput source="code" label="table.field.companys.code" />,
    <TextInput source="name" label="table.field.companys.name" />,
    <TextInput source="nameEn" label="table.field.companys.nameEn" />,
    <TextInput source="breifCode" label="table.field.companys.breifCode" />,
    //   <ReferenceInput source="type" reference="dictData" filter={{ dictTypeCode: 'sys_companys_type' }} label="table.field.companys.type">
    //     <AutocompleteInput label="table.field.companys.type" optionValue="value"/>
    //   </ReferenceInput>,
    <SelectInput label="table.field.companys.type" source="type"
        choices={[
            { id: 'shipper', name: 'common.field.shipper' },
            { id: 'customer', name: 'common.field.customer' },
            { id: 'supplier', name: 'common.field.supplier' },
            { id: 'partners', name: 'common.field.partners' }
        ]} />,
    <TextInput source="contact" label="table.field.companys.contact" />,
    <TextInput source="tel" label="table.field.companys.tel" />,
    <TextInput source="email" label="table.field.companys.email" />,
    <TextInput source="pcode" label="table.field.companys.pcode" />,
    <TextInput source="province" label="table.field.companys.province" />,
    <TextInput source="city" label="table.field.companys.city" />,
    <TextInput source="address" label="table.field.companys.address" />,
    <TextInput label="common.field.memo" source="memo" />,
    <SelectInput
        label="common.field.status"
        source="status"
        choices={[
            { id: '1', name: 'common.enums.statusTrue' },
            { id: '0', name: 'common.enums.statusFalse' },
        ]}
        resettable
    />,
]

const CompanysList = () => {
    const translate = useTranslate();
    const [createDialog, setCreateDialog] = useState(false);
    const [drawerVal, setDrawerVal] = useState(false);

    return (
        <Box display="flex">
            <List
                sx={{
                    flexGrow: 1,
                    transition: (theme) =>
                        theme.transitions.create(['all'], {
                            duration: theme.transitions.duration.enteringScreen,
                        }),
                    marginRight: drawerVal ? `${PAGE_DRAWER_WIDTH}px` : 0,
                }}
                title={"menu.companys"}
                empty={false}
                filters={filters}
                sort={{ field: "create_time", order: "desc" }}
                actions={(
                    <TopToolbar>
                        <FilterButton />
                        <MyCreateButton onClick={() => { setCreateDialog(true) }} />
                        <SelectColumnsButton preferenceKey='companys' />
                        <MyExportButton />
                    </TopToolbar>
                )}
                perPage={DEFAULT_PAGE_SIZE}
            >
                <StyledDatagrid
                    preferenceKey='companys'
                    bulkActionButtons={() => <BulkDeleteButton mutationMode={OPERATE_MODE} />}
                    rowClick={(id, resource, record) => false}
                    omit={['id', 'createTime', 'createBy', 'memo']}
                >
                    <NumberField source="id" />
                    <TextField source="name" label="table.field.companys.name" />
                    <TextField source="code" label="table.field.companys.code" />
                    <TextField source="nameEn" label="table.field.companys.nameEn" />
                    <TextField source="breifCode" label="table.field.companys.breifCode" />
                    <DictField source="type" label="table.field.companys.type" dictTypeCode={'sys_companys_type'} />
                    <TextField source="contact" label="table.field.companys.contact" />
                    <TextField source="tel" label="table.field.companys.tel" />
                    <TextField source="email" label="table.field.companys.email" />
                    <TextField source="pcode" label="table.field.companys.pcode" />
                    <TextField source="province" label="table.field.companys.province" />
                    <TextField source="city" label="table.field.companys.city" />
                    <TextField source="address" label="table.field.companys.address" />
                    <TextField source="updateBy$" label="common.field.updateBy" />
                    <DateField source="updateTime" label="common.field.updateTime" showTime />
                    <TextField source="createBy$" label="common.field.createBy" />
                    <DateField source="createTime" label="common.field.createTime" showTime />
                    <BooleanField source="statusBool" label="common.field.status" sortable={false} />
                    <TextField source="memo" label="common.field.memo" sortable={false} />
                    <WrapperField cellClassName="opt" label="common.field.opt">
                        <EditButton sx={{ padding: '1px', fontSize: '.75rem' }} />
                        <DeleteButton sx={{ padding: '1px', fontSize: '.75rem' }} mutationMode={OPERATE_MODE} />
                    </WrapperField>
                </StyledDatagrid>
            </List>
            <CompanysCreate
                open={createDialog}
                setOpen={setCreateDialog}
            />
            <PageDrawer
                title='Companys Detail'
                drawerVal={drawerVal}
                setDrawerVal={setDrawerVal}
            >
            </PageDrawer>
        </Box>
    )
}

export default CompanysList;
